import logging
from pathlib import Path
from functools import partial
import shutil

from .filesystem import for_each_file

logger = logging.getLogger(__name__)

def _remove_file(path: Path):
    path.unlink()

def cli_file_remove(args):

    input_path = args.path.resolve()
    extension = args.ext

    logger.info("Removing files with extension %s from %s",
                extension, input_path)
    for_each_file(input_path, [extension], _remove_file)


def _flatten(parent: Path, path: Path):
    relative_path = path.relative_to(parent)
    relative_dir = relative_path.parent

    new_filename = "_".join(relative_dir.parts)
    new_filename += "_" + path.name
    new_path = parent / new_filename
    shutil.move(path, new_path)
    
def cli_dir_flatten(args):
    
    input_path = args.path.resolve()

    logger.info("Flattening directory at: %s", input_path)
    for_each_file(input_path, [], partial(_flatten, input_path))

   
def add_parser(subparsers):
    
    parser = subparsers.add_parser("file")
    parsers = parser.add_subparsers(required=True)
    
    remove_parser = parsers.add_parser("remove")
    remove_parser.add_argument(
        "--path",
        type=Path,
        help="Path to directory to remove files from",
    )
    remove_parser.add_argument(
        "--ext",
        type=str,
        help="Extension of file to remove",
    )
    remove_parser.set_defaults(func=cli_file_remove)
 
    flatten_parser = parsers.add_parser("flatten")
    flatten_parser.add_argument(
        "--path",
        type=Path,
        help="Path to directory to flatten",
    )
    flatten_parser.set_defaults(func=cli_dir_flatten)
 
