from pathlib import Path

from jgutils.music import collection
from jgutils.serialization import write_model


def cli_music_read(args):
    collection = collection.read(args.collection.resolve())
    write_model(collection)

def cli_music_refresh(args):
    collection.refresh(args.collection.resolve(),
                       args.work_dir.resolve())

def add_parser(subparsers):
    parser = subparsers.add_parser("music")
    parsers = parser.add_subparsers(required=True)
   
    read_parser = parsers.add_parser("read")
    read_parser.add_argument(
        "--collection",
        type=Path,
        default=Path(),
        help="Directory with input music files.",
    )
    read_parser.add_argument(
        "--output_path",
        type=Path,
        default=Path() / "music_collection.json",
        help="Path to save collection info json to.",
    )
    read_parser.set_defaults(func=cli_music_read)

    refresh_parser = parsers.add_parser("refresh")
    refresh_parser.add_argument(
        "--collection",
        type=Path,
        default=Path(),
        help="Directory with the music collection.",
    )
    refresh_parser.add_argument(
        "--work_dir",
        type=Path,
        default=Path(),
        help="Directory for intermediate storage.",
    )
    refresh_parser.set_defaults(func=cli_music_refresh)

